@@ -54,7 +54,7 @@ package Other {
 use Spreadsheet::Edit ':all';
 
 # Use to not prefix rows with "(Spreadsheet::Edit::Magicrow)"
-my $myvisobj = visnew->Objects({objects => 1, show_overloaded_classname => 0});
+my $myvisobj = visnew->Objects({objects => 1, show_classname => 0});
 
 my ($testdata, $inpath) = create_testdata(
     name => "in1",
@@ -601,29 +601,49 @@ check_both('ABCDEFGHIJKL');
 }
 
 # Verify error checks
-# (Varying title_rx may be pointless now that first/last_data_rx are gone...)
-foreach my $trx_val (0,1,undef,$#rows) {
-  my $saved_title_rx = $title_rx;
-  scope_guard { title_rx $saved_title_rx; };
+foreach ([f => 0], [flt => 0, f => 1, flt => undef], [lt => $#rows],
+        )
+{
+  my @pairs = @$_;
+  my @saved = ($first_data_rx, $last_data_rx, $title_rx);
+  scope_guard {
+    first_data_rx $saved[0];
+    last_data_rx  $saved[1];
+    title_rx      $saved[2];
+  };
 
-  title_rx $trx_val;
-  die 'bug:title_rx as getter' unless u(title_rx) eq u($trx_val);
+  while (@pairs) {
+    my ($key,$val) = @pairs[0,1]; @pairs = @pairs[2..$#pairs];
+    if ($key =~ s/f//) {
+      first_data_rx $val;
+      die 'bug:first_data_rx as getter' unless u(first_data_rx) eq u($val);
+    }
+    if ($key =~ s/l//) {
+      last_data_rx $val;
+      die 'bug:last_data_rx as getter' unless u(last_data_rx) eq u($val);
+    }
+    if ($key =~ s/t//) {
+      title_rx $val;
+      die 'bug:title_rx as getter' unless u(title_rx) eq u($val);
+    }
+    die "BUG $key" if $key ne "";
 
-  # rx out of range
-  eval { apply_torx {  } [0..$#rows+1]; }; verif_eval_err;
-  eval { apply_torx {  } [-1..$#rows]; }; verif_eval_err;
-  eval { apply_exceptrx {  } [0..$#rows+1]; }; verif_eval_err;
-  eval { apply_exceptrx {  } [-1..$#rows]; }; verif_eval_err;
+    # rx out of range
+    eval { apply_torx {  } [0..$#rows+1]; }; verif_eval_err;
+    eval { apply_torx {  } [-1..$#rows]; }; verif_eval_err;
+    eval { apply_exceptrx {  } [0..$#rows+1]; }; verif_eval_err;
+    eval { apply_exceptrx {  } [-1..$#rows]; }; verif_eval_err;
 
-  # Attempt to modify read-only sheet variables
-  eval { $num_cols = 33 }; verif_eval_err;
-  eval { $title_rx = 33 }; verif_eval_err;
+    # Attempt to modify read-only sheet variables
+    eval { $num_cols = 33 }; verif_eval_err;
+    eval { $title_rx = 33 }; verif_eval_err;
 
-  # Access apply-related sheet vars outside apply
-  eval { my $i = $rx }; verif_eval_err;
-  eval { my $i = $crow[0] }; verif_eval_err;
-  eval { my $i = $linenum }; verif_eval_err;
-  eval { my $i = $crow{A} }; verif_eval_err;
+    # Access apply-related sheet vars outside apply
+    eval { my $i = $rx }; verif_eval_err;
+    eval { my $i = $crow[0] }; verif_eval_err;
+    eval { my $i = $linenum }; verif_eval_err;
+    eval { my $i = $crow{A} }; verif_eval_err;
+  }
 }
 
 # Flavors of apply
@@ -658,6 +678,29 @@ foreach my $trx_val (0,1,undef,$#rows) {
     }
     apply { $visited{$rx}++; ck_applyargs(0,\@_); } ; ck_apply(2..6);
 
+    first_data_rx 3;
+    apply { $visited{$rx}++; ck_applyargs(0,\@_); } ; ck_apply(3..6);
+    first_data_rx undef;
+    apply { $visited{$rx}++; ck_applyargs(0,\@_); } ; ck_apply(2..6);
+
+    last_data_rx 4;
+    apply { $visited{$rx}++; ck_applyargs(0,\@_); } ; ck_apply(2..4);
+    last_data_rx undef;
+    apply { $visited{$rx}++; ck_applyargs(0,\@_); } ; ck_apply(2..6);
+
+    first_data_rx 0;  # no-op for apply() because <= title_rx
+    apply { $visited{$rx}++; ck_applyargs(0,\@_); } ; ck_apply(2..6);
+    last_data_rx 4;
+    apply { $visited{$rx}++; ck_applyargs(0,\@_); } ; ck_apply(2..4);
+    apply_all { $visited{$rx}++; ck_applyargs(0,\@_); } ; ck_apply(0..6);
+    first_data_rx undef;
+    last_data_rx undef;
+    apply { $visited{$rx}++; ck_applyargs(0,\@_); } ; ck_apply(2..6);
+
+    last_data_rx 0; # less than title_rx+1
+    apply { $visited{$rx}++; ck_applyargs(0,\@_); } ; ck_apply();
+    last_data_rx undef;
+
     apply_all { $visited{$rx}++; ck_applyargs(0,\@_); } ; ck_apply(0..6);
     foreach my $i (0..6) {
       apply_torx { $visited{$rx}++; ck_applyargs(1,\@_); } $i, 0 ; ck_apply($i);
