@@ -3,6 +3,9 @@
 # The author, Jim Avera (jim.avera at gmail) has waived all copyright and
 # related or neighboring rights to the content of this file.
 # Attribution is requested but is not required.
+#
+# PLEASE NOTE that the above applies to THIS FILE ONLY.  Other files in the
+# same distribution or in other collections may have more restrictive terms.
 
 # Common setup stuff, not specifically for test cases.
 # This file is intended to be identical in all my module distributions.
@@ -28,10 +31,16 @@ use Carp;
 
 sub oops(@) {
   my $pkg = caller;
-  my $pfx = "\n";
-  $pfx .= "$pkg " if $pkg ne 'main';
-  $pfx .= "oops:\n";
-  @_ = ($pfx, @_, "\n");
+  my $pfx = "\noops";
+  $pfx .= " in pkg '$pkg'" unless $pkg eq 'main';
+  $pfx .= ":\n";
+  if (defined(&Spreadsheet::Edit::logmsg)) {
+    # Show current apply sheet & row if any.
+    @_=($pfx, &Spreadsheet::Edit::logmsg(@_));
+  } else {
+    @_=($pfx, @_);
+  }
+  push @_,"\n" unless $_[-1] =~ /\R\z/;
   goto &Carp::confess
 }
 
@@ -44,7 +53,7 @@ sub btwN($@) {
   $fn =~ s/(.)\.[a-z]+$/$1/a;
   local $_ = join("",@_);
   s/\n\z//s;
-  printf "%s:%d: %s\n", $fn, $lno, $_;
+  printf STDERR "%s:%d: %s\n", $fn, $lno, $_;
 }
 
 sub import {
@@ -142,7 +151,7 @@ sub import {
   require Guard;
   Guard->import::into($target, qw(scope_guard guard));
 
-  use Data::Dumper::Interp 6.003 (); # 6.003 fixed AUTOLOAD $@ corruption
+  use Data::Dumper::Interp 6.006 ();
   unless (Cwd::abs_path(__FILE__) =~ /Data-Dumper-Interp/) {
     # unless we are testing DDI
     Data::Dumper::Interp->import::into($target,
